config

package
v0.4.8 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 10, 2020 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package config provides configuration-related types and functions.

Index

Constants

const (
	// Filename is the name of the config file without extension.
	Filename string = "verless"

	// ContentDir is the directory for Markdown content.
	ContentDir string = "content"

	// ThemesDir is the directory for verless themes.
	ThemesDir string = "themes"

	// GeneratedDir is the directory which can be used by hook-commands
	// and which gets ignored by the serve command.
	// The directory can exist in each theme directory and in the StaticDir.
	GeneratedDir string = "generated"

	// StaticDir is the directory for static files.
	StaticDir string = "static"

	// OutputDir is the default output directory.
	OutputDir string = "target"
)

Variables

var (
	// GitTag is injected when building a new release.
	GitTag string = "UNDEFINED"
	// GitCommit stores the latest Git commit.
	GitCommit string = "UNKNOWN"
)

Functions

This section is empty.

Types

type Config

type Config struct {
	Version string
	Site    struct {
		Meta   model.Meta
		Nav    model.Nav
		Footer model.Footer
	}
	Plugins []string
	Theme   string
	Types   map[string]*model.Type
	Build   struct {
		Overwrite bool
		Before    []string
	}
}

Config represents the user configuration stored in verless.yml.

func FromFile

func FromFile(path, filename string) (Config, error)

FromFile looks for a configuration file and converts it to a Config.

Jump to