serve

package
v0.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package serve provides verless' core serve functionality.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(fs afero.Fs, ctx Context) error

Run starts a file server serving the already built project For this it uses the provided information of the context.

Types

type Context

type Context struct {
	Path string
	Port uint16
	IP   net.IP
}

Context provides all components required for serving an already built project.

Jump to