watch

package
v0.3.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package watch provides verless' ability to watch a project and react to changes in a verless project.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Run

func Run(ctx Context) error

Run watches a verless project for changes and writes the changed files to the passed Context.ChangedCh channel. To stop the watcher just close the Context.StopCh channel. Context.IgnorePath can be used to ignore a path inside the given Context.Path.

Types

type Context

type Context struct {
	Path       string
	IgnorePath string
	ChangedCh  chan<- string
	StopCh     <-chan bool
}

Context provides all components required for serving an already built project.

Jump to