fs

package
v0.1.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 22, 2020 License: Apache-2.0 Imports: 3 Imported by: 0

Documentation

Overview

Package fs provides functions for filesystem operations.

Index

Constants

This section is empty.

Variables

var (
	// MarkdownOnly is a filter that only lets pass Markdown files.
	MarkdownOnly = func(file string) bool {
		return filepath.Ext(file) == ".md"
	}

	// NoUnderscores is a predefined filter that doesn't let pass
	// files starting with an underscore.
	NoUnderscores = func(file string) bool {
		filename := filepath.Base(file)
		return !strings.HasPrefix(filename, "_")
	}

	// ErrStreaming is returned from StreamFiles.
	ErrStreaming error = nil
)

Functions

func StreamFiles

func StreamFiles(path string, files chan<- string, filters ...func(file string) bool) error

StreamFiles sends files in a given path that match the given filters through the files channel.

Types

This section is empty.

Jump to