out

package
v0.5.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 8, 2021 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package out provides functions for printing output to the user.

Instead of using the standard library, this package should be used for printing user information and logging in general. Note that the out package isn't optimized for hot paths at the moment.

This package is inspired by https://github.com/kubernetes/minikube.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Err

func Err(prefix style.Emoji, format string, a ...interface{})

Err prints a prefixed, formatted text to the error file as a new line.

func T

func T(prefix style.Emoji, format string, a ...interface{})

T prints a prefixed, formatted text to the out file as a new line.

Types

This section is empty.

Directories

Path Synopsis
Package style provides icons, emojis and other stylized items that can be printed to the standard output device.
Package style provides icons, emojis and other stylized items that can be printed to the standard output device.

Jump to