Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Plugin ¶
type Plugin interface {
// ProcessPage will be invoked after parsing the page. Must be safe
// for concurrent usage.
ProcessPage(page *model.Page) error
// PreWrite will be invoked before writing the site.
PreWrite(site *model.Site) error
// PostWrite will be invoked after writing the site.
PostWrite() error
}
Plugin represents a built-in verless plugin.
type PrePostProcessPlugin ¶ added in v0.5.3
type PrePostProcessPlugin interface {
Plugin
// PreProcessPages will be invoked before all pages get processed.
// So this will be called only once.
PreProcessPages() error
// PostProcessPages will be invoked after all pages were processed.
// So this will be called only once.
PostProcessPages() error
}
Directories
¶
| Path | Synopsis |
|---|---|
|
Package atom provides and implements the atom plugin.
|
Package atom provides and implements the atom plugin. |
|
Package related provides and implements the related plugin.
|
Package related provides and implements the related plugin. |
|
Package tags provides and implements the tags plugin.
|
Package tags provides and implements the tags plugin. |
Click to show internal directories.
Click to hide internal directories.