atom

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2020 License: Apache-2.0 Imports: 6 Imported by: 0

Documentation

Overview

Package atom provides and implements the atom plugin.

Index

Constants

const (
	// Key is the public plugin key.
	Key string = "atom"
)

Variables

This section is empty.

Functions

func New

func New(meta *model.Meta, fs afero.Fs, outputDir string) *atom

New creates a new atom plugin that generated a RSS feed with the provided metadata and stores the XML file in outputDir.

Types

This section is empty.

Jump to