Documentation
¶
Overview ¶
Package route provides route-related convenience functions.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func FromPath ¶
FromPath converts a filepath to a valid verless route that can be registered in a route tree.
A filepath like `content/blog/making-barista-quality-espresso.md` will be converted to `/blog/making-barista-quality-espresso`, for example.
func ToSegments ¶
ToSegments returns the individual segments for a route. Those segments represent the nodes for a route tree.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.