test

package
v0.1.4 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Aug 28, 2020 License: Apache-2.0 Imports: 5 Imported by: 0

Documentation

Overview

Package test contains some simple utils for more readable tests. It is based on https://github.com/benbjohnson/testing.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Assert

func Assert(tb testing.TB, condition bool, msg string, v ...interface{})

Assert fails the test if the condition is false.

func Equals

func Equals(tb testing.TB, exp, act interface{}, options ...cmp.Option)

Equals fails the test if exp is not equal to act.

func Ok

func Ok(tb testing.TB, err error)

Ok fails the test if an err is not nil.

Types

This section is empty.

Jump to