writer

package
v0.3.3 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 16, 2020 License: Apache-2.0 Imports: 11 Imported by: 0

Documentation

Overview

Package writer provides the default build.Writer implementation capable of writing the site model to a filesystem.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New(fs afero.Fs, path, outputDir string, recompileTemplates bool) *writer

New creates a new writer that renders the site model in the given filesystem instance to outputDir.

Types

This section is empty.

Jump to