config

package
v0.2.2 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 6, 2020 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package config provides configuration-related types and functions.

Index

Constants

const (
	// Filename is the name of the config file without extension.
	Filename string = "verless"

	// ContentDir is the directory for Markdown content.
	ContentDir string = "content"

	// TemplateDir is the directory for templates.
	TemplateDir string = "templates"

	// AssetDir is the directory for assets.
	AssetDir string = "assets"

	// OutputDir is the default output directory.
	OutputDir string = "target"

	// IndexFile is the filename used as directory index.
	IndexFile string = "index.html"

	// PageTpl is the template file used for model.Page.
	PageTpl string = "page.html"

	// IndexPageTpl is the template file used for model.IndexPage.
	IndexPageTpl string = "index-page.html"
)

Variables

var (
	// GitTag is injected when building a new release.
	GitTag string = "UNDEFINED"
	// GitCommit stores the latest Git commit.
	GitCommit string = "UNKNOWN"
)

Functions

This section is empty.

Types

type Config

type Config struct {
	Version string
	Site    struct {
		Meta   model.Meta
		Nav    model.Nav
		Footer model.Footer
	}
	Plugins []string
	Types   map[string]*model.Type
	Build   struct {
		Overwrite bool
	}
}

Config represents the user configuration stored in verless.yml.

func FromFile

func FromFile(path, filename string) (Config, error)

FromFile looks for a configuration file and converts it to a Config.

Jump to