Documentation
¶
Overview ¶
Package model provides the verless domain entities.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type ListPage ¶ added in v0.3.1
ListPage represents an overview page that is generated for each content sub-directory.
type Node ¶ added in v0.1.7
Node represents an URL like /blog that contains multiple pages, an overview page (ListPage) and child routes.
func NewNode ¶ added in v0.3.1
func NewNode() *Node
NewNode creates a new, fully initialized Node instance.
func (*Node) CreateChild ¶ added in v0.3.1
CreateChild links a child node to the current node by the given edge name. If there's already a node behind the edge name, it will be overwritten.
type Page ¶
type Page struct {
Route string
ID string
Href string
Title string
Author string
Date time.Time
Tags []Tag
Img string
Credit string
Description string
Content string
Related []*Page
Type *Type
Hidden bool
// contains filtered or unexported fields
}
Page represents a sub-page of the website.
func (*Page) AddProvidedRelated ¶ added in v0.2.0
AddProvidedRelated adds a new Fully Qualified Name URI to the page.
func (*Page) IsCustomListPage ¶ added in v0.4.8
IsCustomListPage returns whether the page is a custom list page that has been created from a file called index.md in a content directory.
func (*Page) ProvidedRelated ¶ added in v0.2.0
ProvidedRelated returns all Fully Qualified Name URIs related to the page.
func (*Page) ProvidedType ¶ added in v0.2.0
ProvidedType returns the user-provided page type.
func (*Page) SetProvidedType ¶ added in v0.2.0
SetProvidedType sets the user-provided page type.
type Site ¶
Site represents the actual website. The site model is generated and populated with data and content during the website build.
Any build.Writer implementation is capable of rendering this model as a static website.