tags

package
v0.4.6 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Oct 4, 2020 License: Apache-2.0 Imports: 4 Imported by: 0

Documentation

Overview

Package tags provides and implements the tags plugin.

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func New

func New() *tags

New creates a new tags plugin that uses templates from the given build path and outputs the tag directories to outputDir.

Types

This section is empty.

Jump to