tags

package
v0.3.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Sep 12, 2020 License: Apache-2.0 Imports: 2 Imported by: 0

Documentation

Overview

Package tags provides and implements the tags plugin.

Index

Constants

const (
	// Key is the public plugin key.
	Key string = "tags"
)

Variables

This section is empty.

Functions

func New

func New() *tags

New creates a new tags plugin that uses templates from the given build path and outputs the tag directories to outputDir.

Types

This section is empty.

Jump to