Documentation
¶
Overview ¶
Package theme provides functions for working with verless themes.
Instead of juggling around with theme paths on your own, you should use the convenience functions from this package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Dir ¶
Dir returns the directory path for the theme with the given name inside the given path. Dir does not ensure that the directory physically exists.
func Exists ¶
Exists determines whether a theme with the provided name inside the given path exists.
func GeneratedDir ¶
GeneratedDir returns the generated directory path of a given theme.
func RunBeforeHooks ¶
RunBeforeHooks executes all pre-build commands specified in the configuration of the theme with the specified name.
Note that the command context directory is the the theme directory instead of the project directory.
func TemplateDir ¶
TemplateDir returns the template directory path of a given theme.